﻿using System;
using System.Linq;
using System.Windows;
using Infragistics.Controls.Grids;
using Infragistics.Documents.Excel;

namespace SpreadsheetDropdownIssueSample
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			Spreadsheet.CommandExecuting += SpreadsheetOnCommandExecuting;
		}

		private void SpreadsheetOnCommandExecuting(object sender, SpreadsheetCommandExecutingEventArgs e)
		{
			if (e.Command != SpreadsheetCommandType.Cut)
				return;

			var endColumn = GetLastUsedColumn();
			var selectedRegion = GetActiveSelection();
			if (selectedRegion.LastColumn <= endColumn)
				return;

			var startRow = selectedRegion.FirstRow;
			var endRow = selectedRegion.LastRow;
			var startColumn = selectedRegion.FirstColumn;

			Spreadsheet.ActiveSelection.ReplaceActiveCellRange(
				new SpreadsheetCellRange(startRow, startColumn, endRow, endColumn),
				new SpreadsheetCell(startRow, startColumn));
		}

		private int GetLastUsedColumn()
			=> Spreadsheet.ActiveWorksheet.Rows.FirstOrDefault()?.Cells.Max(c => c.ColumnIndex) ?? 0;

		private WorksheetRegion GetActiveSelection()
			=> Spreadsheet.ActiveWorksheet.GetRegion(
				Spreadsheet.ActiveSelection.CellRangesAddress,
				CellReferenceMode.A1);

		private void MainWindow_OnInitialized(object sender, EventArgs e)
		{
			Spreadsheet.Workbook = Workbook.Load("SampleSheet.xlsx");
		}
	}
}
